Struct embedded_hal_mock::I2cMock[][src]

pub struct I2cMock<'a> { /* fields omitted */ }

Methods

impl<'a> I2cMock<'a>
[src]

Set data that will be read by read().

Return the data that was written by the last write command.

Return the address that was used by the last read or write command.