Struct embedded_hal_mock::I2cMock [−][src]
pub struct I2cMock<'a> { /* fields omitted */ }Methods
impl<'a> I2cMock<'a>[src]
impl<'a> I2cMock<'a>pub fn new() -> Self[src]
pub fn new() -> Selfpub fn set_read_data(&mut self, data: &'a [u8])[src]
pub fn set_read_data(&mut self, data: &'a [u8])Set data that will be read by read().
pub fn get_write_data(&self) -> &[u8][src]
pub fn get_write_data(&self) -> &[u8]Return the data that was written by the last write command.
pub fn get_last_address(&self) -> Option<u8>[src]
pub fn get_last_address(&self) -> Option<u8>Return the address that was used by the last read or write command.